AUR-INFO
--------
Helper program to show package info for a package from Arch User Repository.

Usage
-----
After downloading:

```chmod +x aur_info.py```

.., and then ...

 ```aur_info.py -p <package_name>```

 Notes
------
 Do ensure that the package_name is correct. To find packages use another tool call aur-search.
